pub struct CompiledCondition {
pub field: Option<String>,
pub predicates: Vec<(ConditionOperator, f64)>,
}Expand description
Compiled threshold condition with one or more predicates (supports ranges).
Fields
field: Option<String>Optional field name for value_count, value_sum, value_avg, value_percentile.
predicates: Vec<(ConditionOperator, f64)>One or more predicates to satisfy (all must be true for the condition to match).
Implementations