EvalError

Enum EvalError 

pub enum EvalError {
Show 13 variants InvalidRegex(Error), InvalidCidr(AddrParseError), Base64(String), UnknownDetection(String), InvalidModifiers(String), IncompatibleValue(String), ExpectedNumeric(String), Parser(SigmaParserError), CorrelationError(String), UnknownRuleRef(String), CorrelationCycle(String), Ir(String), HirCache(String),
}
Errors that can occur during rule compilation or evaluation.

Variants



InvalidRegex(Error)

A regex pattern failed to compile.



InvalidCidr(AddrParseError)

A CIDR pattern failed to parse.



Base64(String)

A base64 operation failed.



UnknownDetection(String)

A detection referenced in a condition was not found.



InvalidModifiers(String)

A modifier combination is invalid.



IncompatibleValue(String)

A value type is incompatible with the modifier.



ExpectedNumeric(String)

A numeric value was expected but not found.



Parser(SigmaParserError)

A parser error propagated during compilation.



CorrelationError(String)

A correlation rule compilation or evaluation error.



UnknownRuleRef(String)

A rule referenced by a correlation was not found.



CorrelationCycle(String)

A cycle was detected in correlation rule references.



Ir(String)

An error from the IR lowering pipeline that has no more specific mapping.



HirCache(String)

A HIR cache (de)serialization error.