pub enum MatchReason {
Matched,
FieldAbsent,
ValueMismatch,
CaseMismatch,
Existence,
NoKeywordMatch,
}Expand description
Why a single leaf matched or did not.
Variants
Matched
The leaf matched.
FieldAbsent
The field is not present in the event.
ValueMismatch
The field is present but the value does not satisfy the matcher.
CaseMismatch
The field is present and matches except for letter case.
Existence
An existence assertion (|exists) was not satisfied.
NoKeywordMatch
A keyword item found no matching string anywhere in the event.