pub enum OnUnknown {
Warn,
Drop,
Passthrough,
Error,
}Expand description
What to do with an event whose schema matched no signature.
Variants
Warn
Evaluate against the default pipeline-set and log a warning.
Drop
Drop the event without evaluating.
Passthrough
Evaluate against the default pipeline-set without logging.
Error
Drop the event and flag it as an error (non-zero exit / error counter).