pub fn load_schema_config(
path: &Path,
) -> Result<(Vec<SchemaSignature>, Option<RoutingConfig>), SchemaError>Expand description
Load both the user signatures and the optional routing section from a YAML file path.
pub fn load_schema_config(
path: &Path,
) -> Result<(Vec<SchemaSignature>, Option<RoutingConfig>), SchemaError>Load both the user signatures and the optional routing section from a YAML file path.