pub fn parse_schema_config(
yaml: &str,
) -> Result<(Vec<SchemaSignature>, Option<RoutingConfig>), SchemaError>Expand description
Parse both the user signatures and the optional routing section from a YAML string.
pub fn parse_schema_config(
yaml: &str,
) -> Result<(Vec<SchemaSignature>, Option<RoutingConfig>), SchemaError>Parse both the user signatures and the optional routing section from a YAML string.