pub struct SchemaMatch {
pub name: String,
pub specificity: u32,
}Expand description
The result of classifying an event: the matched schema name and the specificity of the signature that matched.
Fields
name: Stringspecificity: u32Trait Implementations
Sourceimpl Clone for SchemaMatch
impl Clone for SchemaMatch
Sourcefn clone(&self) -> SchemaMatch
fn clone(&self) -> SchemaMatch
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SchemaMatch
impl Debug for SchemaMatch
impl Eq for SchemaMatch
Sourceimpl PartialEq for SchemaMatch
impl PartialEq for SchemaMatch
Sourcefn eq(&self, other: &SchemaMatch) -> bool
fn eq(&self, other: &SchemaMatch) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SchemaMatch