pub struct UnknownShapeEntry {
pub keys: Vec<String>,
pub count: u64,
}Expand description
A redacted field-key shape of unknown events, for signature authoring.
Fields
keys: Vec<String>The sorted, deduplicated field keys of the unknown events (values are never captured, only key names).
count: u64Number of unknown events with this exact key shape since the last reset.